@@ -66,6 +66,7 @@ from tacotoolbox._column_utils import (
     read_metadata_file,
 )
 
+
 def extract(
     dataset: TacoDataset,
     output: str | Path,
@@ -240,6 +241,7 @@ def _copy_single_file(vsi_path: str, dest_path: Path) -> None:
         # Regular file copy
         shutil.copy2(vsi_path, dest_path)
 
+
 def _copy_folder_recursive(
     folder_row: dict,
     output: Path,
@@ -298,15 +300,14 @@ def _copy_folder_recursive(
         children_df = pl.from_arrow(
             dataset._duckdb.execute(
                 f'SELECT * FROM {view_name} WHERE "internal:parent_id" = ? AND "internal:source_file" = ?',
-                [parent_id, folder_row["internal:source_file"]]
+                [parent_id, folder_row["internal:source_file"]],
             ).fetch_arrow_table()
         )
     else:
         # Single TACO case: only filter by parent_id
         children_df = pl.from_arrow(
             dataset._duckdb.execute(
-                f'SELECT * FROM {view_name} WHERE "internal:parent_id" = ?',
-                [parent_id]
+                f'SELECT * FROM {view_name} WHERE "internal:parent_id" = ?', [parent_id]
             ).fetch_arrow_table()
         )
 
@@ -515,4 +516,4 @@ def _generate_collection_json(dataset: TacoDataset, output: Path) -> None:
     # Write to file
     output_path = output / "COLLECTION.json"
     with open(output_path, "w") as f:
-        json.dump(collection, f, indent=4)
\ No newline at end of file
+        json.dump(collection, f, indent=4)
