@@ -67,9 +67,9 @@ def _import_tqdm():
         tuple: (tqdm_class, is_available)
     """
     try:
-        from tqdm.auto import tqdm  # type: ignore[import-untyped]
+        from tqdm.auto import tqdm
     except ImportError:
-        # Fallback: dummy tqdm that does nothing
+
         class DummyTqdm:
             def __init__(
                 self, iterable=None, total=None, desc=None, disable=None, **kwargs
@@ -260,6 +260,11 @@ class Territorial(TortillaExtension):
         Returns:
             List of property dictionaries, one per input point, containing
             all requested variable values plus the original row index.
+
+        Note:
+            When using mode() reducer, Earth Engine may return "mode", "mode_1", "mode_2"
+            instead of the renamed band names. This function handles renaming them back
+            to the expected variable names.
         """
         # Create Earth Engine FeatureCollection from coordinate points
         fc = ee.FeatureCollection(
@@ -281,6 +286,17 @@ class Territorial(TortillaExtension):
                 reducer=reducer,
                 scale=self.scale_m,
             ).getInfo()
+
+            # Handle mode() reducer: EE returns "mode", "mode_1", "mode_2" instead of band names
+            if "Reducer.mode" in str(reducer):
+                mode_cols = ["mode"] + [f"mode_{j}" for j in range(1, len(products))]
+                for feature in data["features"]:
+                    props = feature.get("properties", {})
+                    for j, product in enumerate(products):
+                        mode_col = mode_cols[j]
+                        if mode_col in props:
+                            props[product["name"]] = props.pop(mode_col)
+
             all_results.append(data["features"])
 
         # Merge results from different reducers by feature index
@@ -291,6 +307,7 @@ class Territorial(TortillaExtension):
             for feature_list in all_results:
                 props.update(feature_list[i].get("properties", {}))
             merged.append(props)
+
         return merged
 
     def _reduce_chunk_with_retry(
